FrameGrabberInterfacesRefactor5 {#master}
-------------------------------

## Libraries

### `dev`

#### `IFrameGrabberImage`

* The `getImageCrop` method has now a working default implementation.

#### `IFrameGrabberImageRaw`

* The `getImageCrop` method has now a working default implementation.
